callMethod method
Searches the method named name in the all the TouchBar items
and execute it.
It returns true if a method of the given name was found and executed.
The name has the value of Identifier.toString().
It is not a humand readable name nor the name of the property that it
holds.
The arguments can be any value.
This method should not be called manually.
Implementation
@override
bool callMethod(String name, dynamic arguments) {
for (AbstractTouchBarItem child in children) {
if (child is CallableItem && child.callMethod(name, arguments) == true) {
return true;
}
}
return false;
}